==> phyloregion_1.0.2.tar.gz: phyloregion/R/plot.swatch.R <==
#' Plot shapefile polygons based on slot values
#'
#' \code{plot_swatch} maps discretized values of a quantity based on their
#' quantiles.
#'
#' @param x A data frame or object of the class SpatialPolygonsDataFrame
#' @param values Variable in the SpatialPolygonsDataFrame for which to
#' discretize the values of the quantity.
#' @param k Numeric, the desired number of bins to discretize.
#' @param palette name of the palette to generate colors from. The name is
#' matched to the list of available color palettes from the \code{hcl.colors}
#' function in the \code{grDevices} package.
#' @param leg Numeric, length of the legend
#' @param key_label label for the color key
#' @param legend logical indicating whether to add a legend to the map.
#' @param pos location to position the legend such as \dQuote{bottomright},
#' \dQuote{bottomleft}, \dQuote{topleft}, and \dQuote{topright}.
#' @param lwd numeric, line width of the legend.
#' @param border plot polygons in SpatialPolygons object
#' @param \dots Further arguments passed to or from other methods.
#' @rdname plot_swatch
#' @keywords visualization and mapping
#' @importFrom stats quantile
#' @importFrom graphics legend par points rect segments strheight strwidth text
#' @importFrom graphics xinch yinch
#' @importFrom grDevices rgb hcl.colors as.graphicsAnnot xy.coords
#' @importFrom stats median
#' @return Returns no value, just map swatch of colors in geographic space!
#' @seealso \code{\link[sp]{SpatialPolygons-class}}
#' @author Barnabas H. Daru \email{darunabas@@gmail.com}
#'
#' @examples
#' library(sp)
#' s <- readRDS(system.file("nigeria/SR_Naija.rds", package = "phyloregion"))
#' plot_swatch(s, values = s$SR, k = 20)
#' @export
plot_swatch <- function(x, values, k = 10, palette = "Blue-Red 3",
                        key_label = "", leg = 10, lwd = 15, pos = "bottomleft",
                        legend = TRUE, border=par("fg"), ...) {
  ed <- FALSE
  if(inherits(x, "phyloregion")){
    x <- x$evol_distinct
    values <- x$ED
    k <- nrow(x)
    ed <- TRUE
  }
  x$values <- values
  colrs <- hcl.colors(k, palette = palette, ...)
  y <- choropleth(values, k, ...) # , style = style
  plot(x, col = colrs[y], border=border, ...)
  if(ed) text(x, labels = as.character(x@data$cluster), ...)
  if (legend) {
    color_key(x, colrs, vals = values, lab = key_label, pos = pos, leg = leg,
              lwd = lwd)
  }
}

==> phyloregion_1.0.4.tar.gz: phyloregion/R/plot.swatch.R <==
#' Plot shapefile polygons based on slot values
#'
#' \code{plot_swatch} maps discretized values of a quantity based on their
#' quantiles.
#'
#' @param x A data frame or object of the class SpatialPolygonsDataFrame
#' @param values Variable in the SpatialPolygonsDataFrame for which to
#' discretize the values of the quantity.
#' @param k Numeric, the desired number of bins to discretize.
#' @param palette name of the palette to generate colors from. The name is
#' matched to the list of available color palettes from the
#' \code{\link[grDevices:palettes]{hcl.colors}} function.
#' @param leg Numeric, length of the legend
#' @param key_label label for the color key
#' @param legend logical indicating whether to add a legend to the map.
#' @param breaks one of \dQuote{equal}, \dQuote{pretty}, \dQuote{jenks},
#' \dQuote{quantile} or numeric with the actual breaks by specifying
#' the minimum (\code{min}) and maximum (\code{max}) bounds.
#' @param pos location to position the legend such as \dQuote{bottomright},
#' \dQuote{bottomleft}, \dQuote{topleft}, and \dQuote{topright}.
#' @param lwd numeric, line width of the legend.
#' @param border plot polygons in SpatialPolygons object
#' @param min the minima of the lowest bound of the break.
#' @param max the maxima of the upper bound of the break
#' @param \dots Further arguments passed to or from other methods.
#' @rdname plot_swatch
#' @keywords visualization and mapping
#' @importFrom stats quantile
#' @importFrom graphics legend par points rect segments strheight strwidth text
#' @importFrom graphics xinch yinch
#' @importFrom grDevices rgb hcl.colors as.graphicsAnnot xy.coords
#' @importFrom stats median
#' @return Returns no value, just map swatch of colors in geographic space!
#' @seealso \code{\link[sp]{SpatialPolygons-class}}
#' @author Barnabas H. Daru \email{darunabas@@gmail.com}
#'
#' @examples
#' library(sp)
#' s <- readRDS(system.file("nigeria/SR_Naija.rds", package = "phyloregion"))
#' plot_swatch(s, values = s$SR, k = 20)
#' @export
plot_swatch <- function(x, values=NULL, k = 10, palette = "Blue-Red 3",
                        key_label = "", leg = 10, lwd = 15, pos = "bottomleft",
                        legend = TRUE, border=par("fg"), breaks = "quantile",
                        min = NULL, max = NULL, ...) {
  ed <- FALSE
  rev <- FALSE
  if(inherits(x, "phyloregion")){
    x <- x$evol_distinct
    if(is.null(values)) values <- x$ED
    k <- nrow(x)
    ed <- TRUE
    rev <- TRUE
  }
  if(is.null(values)) stop("You need to supply value argument!")
  x$values <- values
  colrs <- hcl.colors(k, palette = palette, rev=rev)
  y <- choropleth(values, k, breaks = breaks, min, max) # , style = style
  plot(x, col = colrs[y], border = border, ...)
  if(ed) text(x, labels = as.character(x@data$cluster), ...)
  if (legend) {
    color_key(x, colrs, vals = values, lab = key_label, pos = pos, leg = leg,
              lwd = lwd)
  }
}
